﻿using System;
using System.Web.Mvc;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.MvcEdition;
using System.Linq;
using System.Text;

namespace DisplayASimpleMap.Controllers
{
    public class DisplayASimpleMapController : Controller
    {
        public ActionResult DisplayASimpleMap()
        {
            Map map = new Map("Map1",
                    new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage),
                    510);
            map.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));
            map.MapUnit = GeographyUnit.Meter;

            GoogleOverlay googleOverlay = new GoogleOverlay("google overlay");
            map.CustomOverlays.Add(googleOverlay);

            Proj4Projection proj4 = new Proj4Projection();
            proj4.InternalProjectionParametersString = Proj4Projection.GetDecimalDegreesParametersString();
            proj4.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();

            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(Server.MapPath("~/App_Data/cntry02.shp"));
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
            worldLayer.FeatureSource.Projection = proj4;

            //If we don't need render this layer, just disable this layer.
            worldLayer.IsVisible = false;

            LayerOverlay staticOverlay = new LayerOverlay("worldoverlay");
            staticOverlay.IsBaseOverlay = false;
            staticOverlay.Layers.Add("worldLayer", worldLayer);
            map.CustomOverlays.Add(staticOverlay);

            CloudPopup featureinfoPopup = new CloudPopup("featureInfoPopup", new PointShape(0, 0), "State Info"); // make the popup out of map view temporarily
            featureinfoPopup.AutoSize = true;
            featureinfoPopup.HasCloseButton = true;
            featureinfoPopup.IsVisible = false;
            map.Popups.Add(featureinfoPopup);

            return View(map);
        }

        [MapActionFilter]
        public string ClickEvent(Map map, GeoCollection<object> args)
        {
            PointShape worldCoordinate = new PointShape(Convert.ToDouble(args[0]), Convert.ToDouble(args[1]));

            ShapeFileFeatureLayer worldLayer = (map.CustomOverlays["worldoverlay"] as LayerOverlay).Layers["worldLayer"] as ShapeFileFeatureLayer;

            worldLayer.Open();

            Feature hoverOnFeature = worldLayer.QueryTools.GetFeaturesContaining(new Feature(worldCoordinate.X, worldCoordinate.Y), ReturningColumnsType.AllColumns).FirstOrDefault();
            StringBuilder popupHtml = new StringBuilder("<p>");
            if (hoverOnFeature != null)
            {
                popupHtml.Append(hoverOnFeature.ColumnValues["CNTRY_NAME"]);
            }
            else
            {
                popupHtml.Append("No Contry Here");
            }
            popupHtml.Append("</p>");

            return popupHtml.ToString();
        }
    }
}